@@ -16,7 +16,7 @@ sub get_files {
         return if $File::Find::name =~ m{\A\.pc};
         push @files, substr($File::Find::name,length($directory)+1) if ! -d $_;
     }, $directory);
-    return @files;
+    return sort @files;
 }
 
 =head1 NAME
